---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: enhancement
assignees: ''
---

<!--

⚠️ BEFORE SUBMITTING, READ:

We're excited for your request! However, here are things we are not interested in:

- Decorators.
- Doing the same thing in multiple ways.    
- Adding more layers of abstraction... tree-depth should be 1 at most.
- Features that over-engineer or complicate the code internals.    
- Linters, and crud that complicates projects.    

-->

----

## 🚀 Feature

<!-- A clear and concise description of the feature proposal -->

### Motivation

<!--
Please outline the motivation for the proposal.
Is your feature request related to a problem? e.g., I'm always frustrated when [...].
If this is related to another GitHub issue, please link here too...
-->

### Pitch

<!-- A clear and concise description of what you want to happen. -->

### Alternatives

<!-- A clear and concise description of any alternative solutions or features you've considered, if any. -->

### Additional context

<!-- Add any other context or screenshots about the feature request here. -->
